package com.ruoyi.sim.mapper;

import java.util.List;

import com.ruoyi.sim.domain.Sim;

/**
 * 模拟器Mapper接口
 *
 * @author tom
 * @date 2024-12-13
 */
public interface SimMapper {
    /**
     * 查询模拟器
     *
     * @param simId 模拟器主键
     * @return 模拟器
     */
    public Sim selectSimBySimId(Long simId);

    /**
     * 查询模拟器列表
     *
     * @param sim 模拟器
     * @return 模拟器集合
     */
    public List<Sim> selectSimList(Sim sim);

    /**
     * 新增模拟器
     *
     * @param sim 模拟器
     * @return 结果
     */
    public int insertSim(Sim sim);

    /**
     * 修改模拟器
     *
     * @param sim 模拟器
     * @return 结果
     */
    public int updateSim(Sim sim);

    /**
     * 删除模拟器
     *
     * @param simId 模拟器主键
     * @return 结果
     */
    public int deleteSimBySimId(Long simId);

    /**
     * 批量删除模拟器
     *
     * @param simIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSimBySimIds(Long[] simIds);
}
